@@ -53,11 +53,6 @@ class H2OAutoMLRegressor(H2OAutoML):
                  keepCrossValidationModels=False,
                  keepCrossValidationFoldAssignment=False,
                  exportCheckpointsDir=None,
-                 distribution="AUTO",
-                 tweediePower=1.5,
-                 quantileAlpha=0.5,
-                 huberAlpha=0.9,
-                 customDistributionFunc=None,
                  labelCol="label",
                  foldCol=None,
                  weightCol=None,
